SVG — Kivy v1.0.1-dev documentation

# SVG

Abstraction layer for loading SVG files.

class `kivy.core.svg.` `Svg`(arg, **kwargs)

  Bases: `object`

  Load and draw an SVG file.

  Parameters : | filename: str Path to the svg that should be loaded. keep_data: bool, default to False Keep the raw svg data when the display list is created scale: float, default to 1.0 Scale of the svg anchor_x: float, default to 0 X anchor (x coordinate based on original width, which will be at x pos and used as center for scaling) anchor_y: float, default to 0 Y anchor (y coordinate based on original height, which will be at y pos and used as center for scaling)

  `filename`

    Get/set the filename of svg

  static `load`(filename, **kwargs)

    Load an Svg file

    Parameters : | filename: str Filename of the image